| Title: | Badge for R Package |
|---|---|
| Description: | Query information and generate badge for using in README and GitHub Pages. |
| Authors: | Guangchuang Yu [aut, cre] (ORCID: <https://orcid.org/0000-0002-6485-8781>), Gregor de Cillia [ctb], Dirk Eddelbuettel [ctb], Maëlle Salmon [ctb], Robrecht Cannoodt [ctb] (ORCID: <https://orcid.org/0000-0003-3641-729X>, github: rcannood), Alexander Rossell Hayes [ctb] (ORCID: <https://orcid.org/0000-0001-9412-0457>, github: rossellhayes), Waldir Leoncio [ctb], Matthew Schuelke [ctb] (ORCID: <https://orcid.org/0000-0001-5755-1725>, github: the-mad-statter) |
| Maintainer: | Guangchuang Yu <[email protected]> |
| License: | Artistic-2.0 |
| Version: | 0.2.5 |
| Built: | 2026-05-12 09:43:59 UTC |
| Source: | https://github.com/guangchuangyu/badger |
altmetric badge
badge_altmetric(id, color, alt = NULL)badge_altmetric(id, color, alt = NULL)
id |
altmetric id |
color |
color of badge |
alt |
Alternative text |
badge in markdown syntax
Guangchuang Yu
## Not run: badge_altmetric("2788597", "blue") ## End(Not run)## Not run: badge_altmetric("2788597", "blue") ## End(Not run)
badge of bioconductor download number
badge_bioc_download(pkg = NULL, by, color, type = "distinct", alt = NULL)badge_bioc_download(pkg = NULL, by, color, type = "distinct", alt = NULL)
pkg |
package. If |
by |
one of total or month |
color |
badge color |
type |
one of distinct and total |
alt |
Alternative text |
badge in markdown syntax
Guangchuang Yu
official Bioconductor download badge (download ranking)
badge_bioc_download_rank(pkg = NULL, alt = "download") badge_download_bioc(pkg = NULL, alt = "download")badge_bioc_download_rank(pkg = NULL, alt = "download") badge_download_bioc(pkg = NULL, alt = "download")
pkg |
package. If |
alt |
Alternative text |
bioc download ranking badge
Guangchuang Yu
badge of bioconductor release version
badge_bioc_release(pkg = NULL, color, alt = NULL)badge_bioc_release(pkg = NULL, color, alt = NULL)
pkg |
package. If |
color |
badge color |
alt |
Alternative text |
badge in markdown syntax
Guangchuang Yu
badge of GitHub code size
badge_code_size(ref = NULL, alt = NULL)badge_code_size(ref = NULL, alt = NULL)
ref |
Reference for a GitHub repository. If |
alt |
Alternative text |
badge in markdown syntax
Gregor de Cillia
badge of codecov code coverage
badge_codecov(ref = NULL, token = NULL, branch = NULL, alt = NULL)badge_codecov(ref = NULL, token = NULL, branch = NULL, alt = NULL)
ref |
Reference for a GitHub repository. If |
token |
Codecov graphing token, needed for private repositories. It can be obtained at https://codecov.io/gh/USER/REPO/branch/BRANCH/graph/ |
branch |
The GitHub branch. If |
alt |
Alternative text |
badge in markdown syntax
Gregor de Cillia
CodeFactor badge
badge_codefactor(ref = NULL, alt = "CodeFactor")badge_codefactor(ref = NULL, alt = "CodeFactor")
ref |
Reference for a GitHub repository. If |
alt |
Alternative text |
badge in markdown syntax
Alexander Rossell Hayes
badge of coveralls code coverage
badge_coveralls(ref = NULL, branch = NULL, alt = NULL)badge_coveralls(ref = NULL, branch = NULL, alt = NULL)
ref |
Reference for a GitHub repository. If |
branch |
The GitHub branch. If |
alt |
Alternative text |
badge in markdown syntax
Gregor de Cillia
CRAN checks badge
badge_cran_checks(pkg = NULL, worst = FALSE, alt = "CRAN checks")badge_cran_checks(pkg = NULL, worst = FALSE, alt = "CRAN checks")
pkg |
package. If |
worst |
logical; if FALSE (default) return "summary" badge. If TRUE, return "worst" badge. |
alt |
Alternative text |
badge in Markdown syntax
Scott Chamberlain (badges API), Maëlle Salmon (function)
badge of CRAN downloads
badge_cran_download( pkg = NULL, type = c("last-month", "last-week", "grand-total"), color = NULL, alt = NULL )badge_cran_download( pkg = NULL, type = c("last-month", "last-week", "grand-total"), color = NULL, alt = NULL )
pkg |
package. If |
type |
type of stats. |
color |
color of badge |
alt |
Alternative text |
badge in markdown syntax
Gregor de Cillia
badge of CRAN version
badge_cran_release(pkg = NULL, color = NULL, alt = NULL)badge_cran_release(pkg = NULL, color = NULL, alt = NULL)
pkg |
package. If |
color |
color of badge |
alt |
Alternative text |
badge in markdown syntax
Gregor de Cillia
custom badge
badge_custom(x, y, color, url = NULL, alt = NULL)badge_custom(x, y, color, url = NULL, alt = NULL)
x |
field 1 |
y |
field 2 |
color |
color |
url |
optional url |
alt |
Alternative text |
customize badge
Guangchuang Yu
dependency badge
badge_dependencies(pkg = NULL, alt = "Dependencies")badge_dependencies(pkg = NULL, alt = "Dependencies")
pkg |
package. If |
alt |
Alternative text |
badge in markdown syntax
Dirk Eddelbuettel
badge of devel version
badge_devel(pkg = NULL, color, alt = NULL)badge_devel(pkg = NULL, color, alt = NULL)
pkg |
package. If |
color |
badge color |
alt |
Alternative text |
badge in markdown syntax
doi badge
badge_doi(doi, color, alt = NULL)badge_doi(doi, color, alt = NULL)
doi |
doi |
color |
color |
alt |
Alternative text |
badge
Guangchuang Yu
badge_doi("10.1111/2041-210X.12628", "green")badge_doi("10.1111/2041-210X.12628", "green")
GitHub Actions badge
badge_github_actions( ref = NULL, action = "R-CMD-check", alt = "R build status" )badge_github_actions( ref = NULL, action = "R-CMD-check", alt = "R build status" )
ref |
Reference for a GitHub repository. If |
action |
The name of the GitHub actions workflow. Defaults to
|
alt |
Alternative text |
badge in markdown syntax
Alexander Rossell Hayes
GitHub Release badge
badge_github_release(ref = NULL, alt = NULL)badge_github_release(ref = NULL, alt = NULL)
ref |
Reference for a GitHub repository. If |
alt |
Alternative text |
badge in markdown syntax
Matt Schuelke
badge of devel version
badge_github_version(pkg = NULL, color, alt = NULL)badge_github_version(pkg = NULL, color, alt = NULL)
pkg |
package. If |
color |
badge color |
alt |
Alternative text |
badge in markdown syntax
Guangchuang Yu
last commit badge
badge_last_commit(ref = NULL, branch = NULL, alt = NULL)badge_last_commit(ref = NULL, branch = NULL, alt = NULL)
ref |
Reference for a GitHub repository. If |
branch |
The GitHub branch. If |
alt |
Alternative text |
badge in markdown syntax
Gregor de Cillia
License badge
badge_license( license = NULL, color = "blue", url = NULL, alt = paste("License:", license) )badge_license( license = NULL, color = "blue", url = NULL, alt = paste("License:", license) )
license |
The license to use. If |
color |
badge color |
url |
The URL of the LICENSE text. If |
alt |
Alternative text |
badge in markdown syntax
Alexander Rossell Hayes
lifecycle badge
badge_lifecycle(stage = "experimental", color = NULL, alt = NULL)badge_lifecycle(stage = "experimental", color = NULL, alt = NULL)
stage |
lifecycle stage See https://lifecycle.r-lib.org/articles/stages.html |
color |
color of the badge. If missing, the color is determined by the stage. |
alt |
Alternative text |
badge in markdown syntax
Gregor de Cillia, Waldir Leoncio
repostatus.org badge
badge_repostatus(status, alt = NULL)badge_repostatus(status, alt = NULL)
status |
project status (Concept, WIP, Suspended, Abandoned, Active, Inactive, Unsupported, Moved). See https://www.repostatus.org/lifecycle for more details. |
alt |
Alternative text |
badge in markdown syntax
Waldir Leoncio
r-universe badge
badge_runiverse(pkg = NULL, user = NULL, alt = "r-universe status badge")badge_runiverse(pkg = NULL, user = NULL, alt = "r-universe status badge")
pkg |
Package name. If |
user |
User name. If |
alt |
Alternative text |
badge in markdown syntax
Alexander Rossell Hayes
SCI citation badge
badge_sci_citation(url, color, alt = NULL)badge_sci_citation(url, color, alt = NULL)
url |
Web of Science url |
color |
color of badge |
alt |
Alternative text |
badge in markdown syntax
Guangchuang Yu
travis-ci badge
badge_travis(ref = NULL, is_commercial = FALSE, branch = NULL, alt = NULL)badge_travis(ref = NULL, is_commercial = FALSE, branch = NULL, alt = NULL)
ref |
Reference for a GitHub repository. If |
is_commercial |
Flag to indicate whether or not to use https://travis-ci.com |
branch |
The GitHub branch. If |
alt |
Alternative text |
badge in markdown syntax
Gregor de Cillia
git award rank
gitaward(user = "guangchuangyu", lang)gitaward(user = "guangchuangyu", lang)
user |
user |
lang |
language |
rank
Guangchuang Yu
get devel version number of specific package
ver_devel(pkg = NULL)ver_devel(pkg = NULL)
pkg |
package. If |
devel version
Guangchuang Yu